@@ -15,9 +15,13 @@
 package org.eclipse.core.tests.internal.alias;
 
 import java.net.URI;
+import java.net.URISyntaxException;
 import java.util.Arrays;
-import org.eclipse.core.filesystem.EFS;
-import org.eclipse.core.filesystem.IFileStore;
+import java.util.List;
+import java.util.stream.Collectors;
+import org.eclipse.core.filesystem.*;
+import org.eclipse.core.internal.filesystem.NullFileStore;
+import org.eclipse.core.internal.filesystem.NullFileSystem;
 import org.eclipse.core.internal.resources.*;
 import org.eclipse.core.resources.*;
 import org.eclipse.core.runtime.*;
@@ -43,6 +47,46 @@ public class BasicAliasTest extends ResourceTest {
 	private IFile lChildLinked;
 	private IPath linkOverlapLocation;
 
+	static class BatFS extends NullFileSystem {
+		static final BatFS instance = new BatFS();
+
+		private BatFS() {
+			super();
+			initialize("batfs");
+		}
+	}
+
+	static class BatFSURI extends NullFileStore {
+		private final URI uri;
+
+		public BatFSURI(String uri) {
+			this(from(uri));
+		}
+
+		private static URI from(String uri) {
+			try {
+				return new URI(uri);
+			} catch (URISyntaxException e) {
+				throw new IllegalArgumentException(e);
+			}
+		}
+
+		public BatFSURI(URI uri) {
+			super(new Path("/not/used"));
+			this.uri = uri;
+		}
+
+		@Override
+		public IFileSystem getFileSystem() {
+			return BatFS.instance;
+		}
+
+		@Override
+		public URI toURI() {
+			return uri;
+		}
+	}
+
 	/**
 	 * Asserts that the two given resources are duplicates in the file system.
 	 * Asserts that both have same location, and same members.  Also asserts
@@ -273,6 +317,103 @@ public class BasicAliasTest extends ResourceTest {
 		project.move(projectDesc, IResource.REPLACE, null);
 	}
 
+	/* Bug570896 */
+//	@Ignore("that is already implemented without the uri via store.getFileSystem().getScheme()")
+//	public void testCompareUriSchemeDistinct() throws URISyntaxException {
+//		// AliasManager requires that different scheme are distinct
+//		// (doesnt actually matter if compare yields +1 or -1 for different values)
+//		String[] urisStrings = { //
+//				"scheme1://authority1/path?query#fragment", //
+//				"scheme2://authority1/path?query#fragment", //
+//		};
+//		assertComparedDistinct(urisStrings);
+//	}
+
+	/* Bug570896 */
+	public void testCompareUriAuthorityDistinct() throws URISyntaxException {
+		// AliasManager requires that different authority (server:port) are distinct
+		// (doesnt actually matter if compare yields +1 or -1 for different values)
+
+		assertComparedDistinct(List.of( //
+				"batfs://authority1/path?query#fragment", //
+				"batfs://authority2/path?query#fragment" //
+		));
+	}
+
+	private void assertComparedDistinct(List<String> urisStrings) {
+		List<BatFSURI> batfsList = urisStrings.stream().map(BatFSURI::new).collect(Collectors.toList());
+		for (BatFSURI bu1 : batfsList) {
+			for (BatFSURI bu2 : batfsList) {
+				if (!bu1.equals(bu2)) {
+					assertTrue("1.0", 0 != bu1.compareTo(bu2));
+				}
+			}
+		}
+	}
+
+	/* Bug570896 */
+	public void testCompareUriPathHierarchy() throws URISyntaxException {
+		// AliasManager requires that the path is ordered such path < path%00
+		// and that any subpath of path yields path < subpath < path%00
+		// for example "foo" < "foo/zzz" < "foo%00"
+
+		assertPreOrdered(List.of( //
+				"batfs://Server/Volume:segment1a", //
+				"batfs://Server/Volume:segment1a/a", //
+				"batfs://Server/Volume:segment1a/a%00", //
+				"batfs://Server/Volume:segment1a/segment2a", //
+				"batfs://Server/Volume:segment1a/segment2a%00", //
+				"batfs://Server/Volume:segment1a/segment2b", //
+				"batfs://Server/Volume:segment1a/segment2b%00", //
+				"batfs://Server/Volume:segment1a%00", //
+				"batfs://Server/Volume:segment2a", //
+				"batfs://Server/Volume:segment2a/b", //
+				"batfs://Server/Volume:segment2a/segment2a", //
+				"batfs://Server/Volume:segment2a/segment2b", //
+				"batfs://Server/Volume:segment2a%00" //
+		));
+	}
+
+	/* Bug570896 */
+	public void testCompareUriOctets() throws URISyntaxException {
+		// uri.getPath() will normalize the octets
+		assertPreOrdered(List.of( //
+				"http://Server/Volume:A", //
+				"http://Server/Volume:%41", // hex 41==Ascii A
+				"http://Server/Volume:A", //
+				"http://Server/Volume:%41" //
+		));
+	}
+
+	/* Bug570896 */
+	public void testCompareUriCase() throws URISyntaxException {
+		// its not a requirement but a back compatibility that the order is
+		// case sensitive even on case insensitive OSes:
+		assertComparedDistinct(List.of( //
+				"http://Server/Volume:a", //
+				"http://Server/Volume:A" // A>a
+		));
+	}
+
+	/* Bug570896 */
+	public void testCompareUriFragment() throws URISyntaxException {
+		// fragments should NOT be distinct! Even though they might not be used:
+		assertPreOrdered(List.of( //
+				"bats://authority/path?query#fragment1", //
+				"bats://authority/path?query#fragment2", //
+				"bats://authority/path?query#fragment1", //
+				"bats://authority/path?query#fragment2" //
+		));
+	}
+
+	private void assertPreOrdered(List<String> urisStrings) {
+		List<BatFSURI> batfsList = urisStrings.stream().map(BatFSURI::new).collect(Collectors.toList());
+		// stable sort:
+		List<BatFSURI> sorted = batfsList.stream().sorted(IFileStore::compareTo).collect(Collectors.toList());
+		// proof sort order did not change
+		assertEquals("1.0", batfsList, sorted);
+	}
+
 	public void testBug256837() {
 		final AliasManager aliasManager = ((Workspace) getWorkspace()).getAliasManager();
 		//force AliasManager to restart (simulates a shutdown/startup)
