@@ -18,8 +18,6 @@ package org.eclipse.core.tests.resources;
 
 import java.io.InputStream;
 import java.net.URI;
-import junit.framework.Test;
-import junit.framework.TestSuite;
 import org.eclipse.core.filesystem.EFS;
 import org.eclipse.core.filesystem.IFileStore;
 import org.eclipse.core.internal.resources.Project;
@@ -42,17 +40,6 @@ public class ProjectSnapshotTest extends ResourceTest {
 	/** test projects that we operate on */
 	protected IProject[] projects = new IProject[2];
 
-	public ProjectSnapshotTest() {
-		super();
-	}
-
-	public ProjectSnapshotTest(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return new TestSuite(ProjectSnapshotTest.class);
-	}
 
 	@Override
 	protected void setUp() throws Exception {
