@@ -15,8 +15,6 @@ package org.eclipse.core.tests.resources.regression;
 
 import java.io.IOException;
 import java.io.InputStream;
-import junit.framework.Test;
-import junit.framework.TestSuite;
 import org.eclipse.core.filesystem.IFileStore;
 import org.eclipse.core.internal.resources.Resource;
 import org.eclipse.core.resources.*;
@@ -30,18 +28,6 @@ import org.eclipse.core.tests.resources.ResourceTest;
  */
 public class Bug_032076 extends ResourceTest {
 
-	public Bug_032076() {
-		super("");
-	}
-
-	public Bug_032076(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return new TestSuite(Bug_032076.class);
-	}
-
 	public void testFileBugOnWindows() {
 		if (!isWindows()) {
 			return;
